==> tine20-humanresources_2019.12.5.tar.bz2: HumanResources/js/HumanResources-lang-it-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of HumanResources **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Italian (http://www.transifex.com/tine20/tine20/language/it/)\nLanguage: it\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "You do not have admin rights on HumanResources"
: "Non si dispone dei permessi di amministratore per le risorse umane"

, "Wage types"
: ""

, "Free time types"
: ""

, "Working time scheme, Working time schemes"
: [
  ""
 ,""

]
, "Book as vacation"
: ""

, "Sickness"
: "Malattia"

, "Sickness Days"
: ""

, "Vacation"
: "Ferie"

, "Vacation Days"
: "giorni di ferie"

, "There could not be found any {0}. Please try to change your filter-criteria or view-options."
: ""

, "Could not book as vacation"
: ""

, "The unexcused sickness days could not be booked as vacation. There are not enough days left!"
: ""

, "Human Resources, Human Resources"
: [
  ""
 ,""

]
, "Template"
: ""

, "Individual"
: ""

, "Shared"
: ""

, "Edit {0} for {1} - {2}"
: ""

, "Extra free time, Extra free times"
: [
  ""
 ,""

]
, "Summary"
: ""

, "Free Times"
: ""

, "Possible vaction days"
: ""

, "Remaining vaction days"
: ""

, "Taken vaction days"
: ""

, "Expired vaction days"
: ""

, "Rebooked vaction days"
: ""

, "Excused sickness days"
: ""

, "Unexcused sickness days"
: ""

, "Working Time"
: ""

, "Days to work"
: ""

, "Hours to work"
: ""

, "Days to work after vacation and sickness"
: ""

, "Hours to work after vacation and sickness"
: ""

, "Miscellaneous"
: ""

, "Description"
: "Descrizione"

, "Employee, Employees"
: [
  "Dipendente"
 ,"Dipendenti"

]
, "Calculate all Reports"
: ""

, "Recalculate"
: ""

, "Cancel"
: "Cancella"

, "OK"
: "OK"

, "Please use the following format: MM-DD"
: ""

, "Calendar"
: "Calendario"

, "Calendars"
: "Calendari"

, "Vacation expires"
: ""

, "Book remaining vacation"
: ""

, "Year"
: ""

, "Please enter the year you want to create accounts for:"
: ""

, "Accounts have been created"
: ""

, "{0} accounts for the year {1} have been created successfully!"
: ""

, "Create new accounts"
: ""

, "Booking has been successfull!"
: ""

, "The remaining vacation days of the selected accounts have been booked successfully!"
: ""

, "CostCenter, CostCenters"
: [
  "Centro Costi"
 ,"Centro Costi"

]
, "Cost Center, Cost Centers"
: [
  ""
 ,"Centro di costo"

]
, "Startdate"
: "Data inizio"

, "Contract, Contracts"
: [
  "Contratto"
 ,"Contratti"

]
, "Vacation in same period"
: ""

, "There are some vacation days matching the period of the contract you added. After saving this employee, changing the contract is not possible anymore."
: ""

, "Edit {0}"
: ""

, "Working Time Rules"
: ""

, "Start Date"
: "Data inizio"

, "End Date"
: "Data Fine"

, "Feast Calendar"
: "Calendario Festività"

, "Vacation days of one calendar year"
: ""

, "Working Time Schema"
: ""

, "Working Hours per week"
: "Ore lavorative settimanali"

, "Mon."
: "Lun."

, "Tue."
: "Mar."

, "Wed."
: "Mer."

, "Thu."
: "Gio."

, "Fri."
: "Ven."

, "Sat."
: "Sab."

, "Sun."
: "Dom."

, "Edit {0} \"{1}\""
: ""

, "Edit {0} for {1}"
: ""

, "Add {0} for {1}"
: ""

, "You have to select at least one day to save this sickness entry."
: ""

, "You have to select at least one day to save this vacation entry."
: ""

, "No day selected"
: ""

, "Personal account, Personal accounts"
: [
  ""
 ,""

]
, "Status"
: "Stato"

, "Remaining"
: ""

, "Select Days"
: "Seleziona Giorni"

, "Enter description"
: "Inserisci descrizione"

, "Account is disabled or deleted!"
: ""

, "Division"
: "Divisione"

, "Health Insurance"
: "Assicurazione sanitaria"

, "Apply contact data on form"
: "Applica i dati del contatto sul modulo"

, "Salutation"
: "Saluto"

, "Personal Information"
: "Informazioni Personali"

, "Country"
: "Stato"

, "Birthday"
: "Compleanno"

, "Internal Information"
: "Informazioni Interne"

, "Banking Information"
: "Informazioni bancarie"

, "Type"
: "Tipo"

, "Template (individual working time schemas are created for each contract)"
: ""

, "Shared (this working time schemas can be shared among contracts)"
: ""

, "Days"
: ""

, "Expiration date"
: ""

, "WK"
: "SET"

, "Loading calendar data..."
: "Caricamento dati calendario..."

, "Year can not be changed"
: ""

, "You have already selected some dates from another year. Please create a new record to add dates from another year!"
: ""

, "No more vacation days"
: ""

, "The Employee has no more possible vacation days left for this year. Create a new vacation and use another personal account the vacation should be taken from."
: ""

, "Excused"
: "Giustificato"

, "Unexcused"
: "Non giustificato"

, "Currently employed"
: "Attualmente impiegato"

, "Employees which are currently employed"
: "I dipendenti che sono attualmente impiegati"

, "All employees"
: ""

, "All available employees"
: ""

, "Payed"
: ""

, "Not payed"
: ""

, "Currently employed employees"
: ""

, "All accounts"
: ""

, "All available accounts"
: ""

, "Full-time 40 hours"
: ""

, "Full-time 37.5 hours"
: ""

, "Part-time 20 hours"
: ""

, "Default wage type"
: ""

, "Salary"
: ""

, "Business trip"
: ""

, "Sunday bonus"
: ""

, "Feast day"
: ""

, "Feast day bonus"
: ""

, "Overtime"
: ""

, "Overtime bonus"
: ""

, "Late shift bonus"
: ""

, "Night bonus"
: ""

, "Break"
: ""

, "Stand by"
: ""

, "Unpaid"
: ""

, "[S] Sickness"
: ""

, "[D] Visit doctor"
: ""

, "[V] Vacation"
: ""

, "[BT] Business trip"
: ""

, "[FT] Flex time"
: ""

, "[BK] Break"
: ""

, "[T] Training"
: ""

, "Freetime Type"
: "Tipo Tempo Disponibile"

, "Possible free time definitions"
: "Possibili definizioni di per il tempo disponibile"

, "Vacation Status"
: "Stato Ferie"

, "Possible vacation status definitions"
: "Possibili definizioni di stato ferie"

, "Requested"
: "Richiesto"

, "In process"
: "In esecuzione"

, "Accepted"
: "Accettato"

, "Declined"
: "Declinato"

, "Sickness Status"
: "Stato Malattia"

, "Possible sickness status definitions"
: "Possibili definizioni di stato di malattia"

, "Default Feast Calendar"
: "Calendario Festività Predifinito"

, "Here you can define the default feast calendar used to set feast days and other free days in datepicker"
: "Qui è possibile definire il calendario predefinito delle festività utilizzato per impostare i giorni di festa e di altri giorni liberi"

, "Enabled Features"
: ""

, "Enabled Features in HumanResources Application."
: ""

, "Calculate Daily Reports"
: ""

, "Activate to calculate daily reports with a nightly scheduler job"
: ""

, "Extra freetime type"
: ""

, "Possible extra free time definitions"
: ""

, "Here you can define the day, when the vacation days taken from last year expires, the format is MM-DD."
: ""

, "Report Templates Node ID"
: ""

, "Timetracker Timeaccount for Workingtime Tracking"
: ""

, "No valid contract for this date"
: ""

, "unexpected error: "
: ""

, "daily wt reports can't be created"
: ""

, "It is not allowed to update a cleared report"
: ""

, "monthly wt reports can't be created"
: ""

, "previous months need to be cleared first"
: ""

, "following months need to be uncleared first"
: ""

, "Daily Working Time Report, Daily Working Time Reports"
: [
  ""
 ,""

]
, "Date"
: ""

, "Evaluation Start Time"
: ""

, "Evaluation End Time"
: ""

, "Corrected Evaluation Start Time"
: ""

, "Corrected Evaluation End Time"
: ""

, "Target Working Time"
: ""

, "Target Working Time Correction"
: ""

, "Break Time Net"
: ""

, "Break Deduction Time"
: ""

, "Working Times"
: ""

, "Actual Working Time"
: ""

, "Working Time Correction"
: ""

, "Total Working Time"
: ""

, "System Remark"
: ""

, "Remark"
: ""

, "Is Cleared"
: ""

, "Calculation Error"
: ""

, "Monthly Working Time Report, Monthly Working Time Reports"
: [
  ""
 ,""

]
, "Month"
: ""

, "Daily Working Time Reports"
: ""

, "Working Time Balance Previous Month"
: ""

, "Total Working Time Balance"
: ""

, "Wage type, Wage types"
: [
  ""
 ,""

]
, "Abbreviation"
: ""

, "Name"
: ""

, "System"
: ""

, "Factor (%)"
: ""

, "Additional Wage"
: ""

, "Quick search"
: ""

, "Extra free times"
: ""

, "Start time"
: ""

, "Break Time, Break Times"
: [
  ""
 ,""

]
, "After exceeding {{time_worked|date(\"H:i\", \"GMT\")}} of working time {{break_time|date(\"H:i\", \"GMT\")}} break time gets deducted automatically."
: ""

, "Time worked"
: ""

, "Break time"
: ""

, "Work Time Limit, Work Time Limits"
: [
  ""
 ,""

]
, "Working time is evaluated from {{start_time|date(\"H:i\")}} until {{end_time|date(\"H:i\")}}."
: ""

, "Absence reason, Absence reasons"
: [
  ""
 ,""

]
, "Allow Booking"
: ""

, "Allow Planning"
: ""

, "Enable Freetime Timetracking"
: ""

, "Timeaccount"
: ""

, "Free Time, Free Times"
: [
  "Tempo Disponibile"
 ,"Tempo Disponibile"

]
, "Account"
: "Account"

, "First Day"
: ""

, "Last Day"
: ""

, "Days Count"
: ""

, "Free Days"
: ""

, "Private Information"
: ""

, "Is employed"
: ""

, "Number"
: "Numero"

, "Transponder Id"
: ""

, "Germany"
: ""

, "Locality"
: "località"

, "Postalcode"
: "CAP"

, "Region"
: "Provincia"

, "Street"
: "Via"

, "Street 2"
: ""

, "E-Mail"
: "E-Mail"

, "Telephone Number"
: "Telefono"

, "Cell Phone Number"
: "Numero Cellulare"

, "Title"
: "Titolo"

, "Last Name"
: "Cognome"

, "First Name"
: "Nome"

, "Employee name"
: "Nome dipendente"

, "Account Holder"
: "Intestatario del conto"

, "Account Number"
: "Numero di conto"

, "Bank Name"
: "Nome Banca"

, "Code Number"
: "Numero di codice"

, "Employment begin"
: "Inizio impiego"

, "Employment end"
: "Fine Impiego"

, "Supervisor"
: "Supervisore"

, "Profession"
: "Professione"

, "Position"
: ""

, "Contracts"
: ""

, "Cost Centers"
: ""

, "Free Day, Free Days"
: [
  "Giorno Diponibile"
 ,"Giorni Diponibili"

]
, "No contract could be found."
: "Non è stato trovato alcun contratto."

, "Please create a contract for this employee!"
: "Si prega di creare un contratto per questo dipendente!"

, "Negative Timespace"
: ""

, "The start date of the contract must be before the end date!"
: ""

, "Not allowed!"
: ""

, "It's only allowed to book remaining vacation days from years in the past!"
: ""

, "Contracts overlap"
: ""

, "The contracts must not overlap!"
: ""

, "No or no valid year given"
: ""

, "Please use a valid year!"
: ""

, "No current contract!"
: ""

, "A current contract could not be found!"
: ""

, "Contract not editable"
: ""

, "You are not allowed to change the record if a vacation has been booked already!"
: ""

, "No personal account found"
: ""

, "An existing personal account could not be found. Please create one!"
: ""

, "edit private employee data"
: "modifica i dati privati dei dipendenti"

, "Edit birthday, account data and other private information of employee records"
: "Modifica compleanno, dati account e altre informazioni private dei dipendenti"


, "Working time scheme"
: ""

, "Human Resources"
: ""

, "Extra free time"
: ""

, "Employee"
: "Dipendente"

, "CostCenter"
: "Centro Costi"

, "Cost Center"
: ""

, "Contract"
: "Contratto"

, "Personal account"
: ""

, "Daily Working Time Report"
: ""

, "Monthly Working Time Report"
: ""

, "Wage type"
: ""

, "Break Time"
: ""

, "Work Time Limit"
: ""

, "Absence reason"
: ""

, "Free Time"
: "Tempo Disponibile"

, "Free Day"
: "Giorno Diponibile"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-humanresources_2020.03.4.tar.bz2: HumanResources/js/HumanResources-lang-it-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of HumanResources **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Italian (http://www.transifex.com/tine20/tine20/language/it/)\nLanguage: it\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "You do not have admin rights on HumanResources"
: "Non si dispone dei permessi di amministratore per le risorse umane"

, "Working time model"
: ""

, "Book as vacation"
: ""

, "Sickness"
: "Malattia"

, "Sickness Days"
: ""

, "Vacation"
: "Ferie"

, "Vacation Days"
: "giorni di ferie"

, "There could not be found any {0}. Please try to change your filter-criteria or view-options."
: ""

, "Could not book as vacation"
: ""

, "The unexcused sickness days could not be booked as vacation. There are not enough days left!"
: ""

, "Human Resources, Human Resources"
: [
  ""
 ,""

]
, "Title"
: "Titolo"

, "Work Start"
: ""

, "Work End"
: ""

, "Edit {0} for {1} - {2}"
: ""

, "Extra free time, Extra free times"
: [
  ""
 ,""

]
, "Summary"
: ""

, "Free Times"
: ""

, "Possible vaction days"
: ""

, "Remaining vaction days"
: ""

, "Taken vaction days"
: ""

, "Expired vaction days"
: ""

, "Rebooked vaction days"
: ""

, "Excused sickness days"
: ""

, "Unexcused sickness days"
: ""

, "Working Time"
: ""

, "Days to work"
: ""

, "Hours to work"
: ""

, "Days to work after vacation and sickness"
: ""

, "Hours to work after vacation and sickness"
: ""

, "Miscellaneous"
: ""

, "Description"
: "Descrizione"

, "Working time Model"
: ""

, "Work start"
: ""

, "not set"
: ""

, "Work end"
: ""

, "Working Hours per week"
: "Ore lavorative settimanali"

, "Mon."
: "Lun."

, "Tue."
: "Mar."

, "Wed."
: "Mer."

, "Thu."
: "Gio."

, "Fri."
: "Ven."

, "Sat."
: "Sab."

, "Sun."
: "Dom."

, "Employee, Employees"
: [
  "Dipendente"
 ,"Dipendenti"

]
, "Cancel"
: "Cancella"

, "OK"
: "OK"

, "Please use the following format: MM-DD"
: ""

, "Calendar"
: "Calendario"

, "Calendars"
: "Calendari"

, "Vacation expires"
: ""

, "Breaks"
: ""

, "Hours"
: ""

, "Break duration"
: ""

, "Book remaining vacation"
: ""

, "Year"
: ""

, "Please enter the year you want to create accounts for:"
: ""

, "Accounts have been created"
: ""

, "{0} accounts for the year {1} have been created successfully!"
: ""

, "Create new accounts"
: ""

, "Booking has been successfull!"
: ""

, "The remaining vacation days of the selected accounts have been booked successfully!"
: ""

, "CostCenter, CostCenters"
: [
  "Centro Costi"
 ,"Centro Costi"

]
, "Cost Center, Cost Centers"
: [
  ""
 ,"Centro di costo"

]
, "Startdate"
: "Data inizio"

, "Contract, Contracts"
: [
  "Contratto"
 ,"Contratti"

]
, "Vacation in same period"
: ""

, "There are some vacation days matching the period of the contract you added. After saving this employee, changing the contract is not possible anymore."
: ""

, "Edit {0}"
: ""

, "Start Date"
: "Data inizio"

, "End Date"
: "Data Fine"

, "Feast Calendar"
: "Calendario Festività"

, "Choose the template"
: "Scegli il modello"

, "Vacation days of one calendar year"
: ""

, "Edit {0} \"{1}\""
: ""

, "Edit {0} for {1}"
: ""

, "Add {0} for {1}"
: ""

, "You have to select at least one day to save this sickness entry."
: ""

, "You have to select at least one day to save this vacation entry."
: ""

, "No day selected"
: ""

, "Personal account, Personal accounts"
: [
  ""
 ,""

]
, "Status"
: "Stato"

, "Remaining"
: ""

, "Select Days"
: "Seleziona Giorni"

, "Enter description"
: "Inserisci descrizione"

, "Account is disabled or deleted!"
: ""

, "Division"
: "Divisione"

, "Health Insurance"
: "Assicurazione sanitaria"

, "Apply contact data on form"
: "Applica i dati del contatto sul modulo"

, "Salutation"
: "Saluto"

, "Personal Information"
: "Informazioni Personali"

, "Country"
: "Stato"

, "Birthday"
: "Compleanno"

, "Internal Information"
: "Informazioni Interne"

, "Banking Information"
: "Informazioni bancarie"

, "Days"
: ""

, "Type"
: "Tipo"

, "Expiration date"
: ""

, "WK"
: "SET"

, "Loading calendar data..."
: "Caricamento dati calendario..."

, "Year can not be changed"
: ""

, "You have already selected some dates from another year. Please create a new record to add dates from another year!"
: ""

, "No more vacation days"
: ""

, "The Employee has no more possible vacation days left for this year. Create a new vacation and use another personal account the vacation should be taken from."
: ""

, "Excused"
: "Giustificato"

, "Unexcused"
: "Non giustificato"

, "Currently employed"
: "Attualmente impiegato"

, "Employees which are currently employed"
: "I dipendenti che sono attualmente impiegati"

, "All employees"
: ""

, "All available employees"
: ""

, "Payed"
: ""

, "Not payed"
: ""

, "Currently employed employees"
: ""

, "All accounts"
: ""

, "All available accounts"
: ""

, "Full-time 40 hours"
: ""

, "Full-time 37.5 hours"
: ""

, "Part-time 20 hours"
: ""

, "Freetime Type"
: "Tipo Tempo Disponibile"

, "Possible free time definitions"
: "Possibili definizioni di per il tempo disponibile"

, "Vacation Status"
: "Stato Ferie"

, "Possible vacation status definitions"
: "Possibili definizioni di stato ferie"

, "Requested"
: "Richiesto"

, "In process"
: "In esecuzione"

, "Accepted"
: "Accettato"

, "Declined"
: "Declinato"

, "Sickness Status"
: "Stato Malattia"

, "Possible sickness status definitions"
: "Possibili definizioni di stato di malattia"

, "Default Feast Calendar"
: "Calendario Festività Predifinito"

, "Here you can define the default feast calendar used to set feast days and other free days in datepicker"
: "Qui è possibile definire il calendario predefinito delle festività utilizzato per impostare i giorni di festa e di altri giorni liberi"

, "Enabled Features"
: ""

, "Enabled Features in HumanResources Application."
: ""

, "Calculate Daily Reports"
: ""

, "Activate to calculate daily reports with a nightly scheduler job"
: ""

, "Extra freetime type"
: ""

, "Possible extra free time definitions"
: ""

, "Here you can define the day, when the vacation days taken from last year expires, the format is MM-DD."
: ""

, "Report Templates Node ID"
: ""

, "Timetracker Timeaccount for Workingtime Tracking"
: ""

, "Daily Working Time Report, Daily Working Time Reports"
: [
  ""
 ,""

]
, "Date"
: ""

, "Evaluation Start Time"
: ""

, "Evaluation End Time"
: ""

, "Paid Absence Time"
: ""

, "Unpaid Absence Time"
: ""

, "Absence"
: ""

, "Break Time Net"
: ""

, "Break Deduction Time"
: ""

, "Feast Time"
: ""

, "Break Time"
: ""

, "Sickness Time"
: ""

, "Working Time Correction"
: ""

, "Actual Working Time"
: ""

, "Target Working Time"
: ""

, "System Remark"
: ""

, "Remark"
: ""

, "Is Cleared"
: ""

, "Cleared in"
: ""

, "Working time, Working times"
: [
  ""
 ,""

]
, "Quick search"
: ""

, "Extra free times"
: ""

, "Free Time, Free Times"
: [
  "Tempo Disponibile"
 ,"Tempo Disponibile"

]
, "Account"
: "Account"

, "First Day"
: ""

, "Last Day"
: ""

, "Days Count"
: ""

, "Free Days"
: ""

, "Private Information"
: ""

, "Is employed"
: ""

, "Number"
: "Numero"

, "Badge Id"
: ""

, "Germany"
: ""

, "Locality"
: "località"

, "Postalcode"
: "CAP"

, "Region"
: "Provincia"

, "Street"
: "Via"

, "Street 2"
: ""

, "E-Mail"
: "E-Mail"

, "Telephone Number"
: "Telefono"

, "Cell Phone Number"
: "Numero Cellulare"

, "Last Name"
: "Cognome"

, "First Name"
: "Nome"

, "Employee name"
: "Nome dipendente"

, "Account Holder"
: "Intestatario del conto"

, "Account Number"
: "Numero di conto"

, "Bank Name"
: "Nome Banca"

, "Code Number"
: "Numero di codice"

, "Employment begin"
: "Inizio impiego"

, "Employment end"
: "Fine Impiego"

, "Supervisor"
: "Supervisore"

, "Profession"
: "Professione"

, "Position"
: ""

, "Contracts"
: ""

, "Cost Centers"
: ""

, "Free Day, Free Days"
: [
  "Giorno Diponibile"
 ,"Giorni Diponibili"

]
, "Break, Breaks"
: [
  ""
 ,""

]
, "Workingtime"
: ""

, "No contract could be found."
: "Non è stato trovato alcun contratto."

, "Please create a contract for this employee!"
: "Si prega di creare un contratto per questo dipendente!"

, "Negative Timespace"
: ""

, "The start date of the contract must be before the end date!"
: ""

, "Not allowed!"
: ""

, "It's only allowed to book remaining vacation days from years in the past!"
: ""

, "Contracts overlap"
: ""

, "The contracts must not overlap!"
: ""

, "No or no valid year given"
: ""

, "Please use a valid year!"
: ""

, "No current contract!"
: ""

, "A current contract could not be found!"
: ""

, "Contract not editable"
: ""

, "You are not allowed to change the record if a vacation has been booked already!"
: ""

, "No personal account found"
: ""

, "An existing personal account could not be found. Please create one!"
: ""

, "edit private employee data"
: "modifica i dati privati dei dipendenti"

, "Edit birthday, account data and other private information of employee records"
: "Modifica compleanno, dati account e altre informazioni private dei dipendenti"

, "Public Holiday Calendar"
: ""

, "Here you can define the default public holiday calendar used to set public holidays and other free days in datepicker"
: ""

, "Public Holidays"
: ""

, "Badge ID"
: ""

, "Human Resources"
: ""

, "Extra free time"
: ""

, "Employee"
: "Dipendente"

, "CostCenter"
: "Centro Costi"

, "Cost Center"
: ""

, "Contract"
: "Contratto"

, "Personal account"
: ""

, "Daily Working Time Report"
: ""

, "Working time"
: ""

, "Free Time"
: "Tempo Disponibile"

, "Free Day"
: "Giorno Diponibile"

, "Break"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
